@@ -61,6 +61,9 @@ CREATE [% keyword %] [% name %][% child_output %]
 
 [% END %]
 );
+[% FOREACH uq_cons_name IN unique_name.keys.sort %]
+CREATE UNIQUE INDEX [% uq_cons_name %] ON [% name %]( [% unique_name.${uq_cons_name}.join(', ') %] );
+[% END %]
 [% END %]
 
 [% BLOCK pk_text %]
@@ -133,8 +136,17 @@ sub output_sql_lite {
         push @{ $output{ table_body } }, $pk_text;
     }
 
+    my $unique_name = $self->find_unique_name(
+            $self->{__NAME__},
+            $lookup,
+    );
+
     my $child_out_str = Bigtop::Backend::SQL::SQLite::table_body(
-        { child_output => $output{table_body} }
+        {
+            child_output => $output{table_body},
+            unique_name  => $unique_name,
+            name         => $self->get_name()
+        }
     );
 
     if ( defined $output{insert_statements} ) {
