@@ -91,8 +91,8 @@ sub do_main {
     my $schema = $self->get_schema();
     my @rows   = $CHILD->get_listing(
         {
-            schema   => $schema,
-            where    => $search,
+            schema      => $schema,
+            where       => $search,
         }
     );
 
@@ -123,7 +123,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj, { skipinvalid => 1 } );
+        my $json = to_json( $obj, { allow_blessed => 1 } );
         return( $json );
     }
 
@@ -137,7 +137,12 @@ sub form {
     my ( $self, $row ) = @_;
 
     my $selections = $CHILD->get_form_selections(
-            { schema => $self->get_schema() }
+        {
+            schema          => $self->get_schema(),
+            foreign_tables  => {
+                'family' => 1,
+            }
+        }
     );
 
     return {
