@@ -97,8 +97,8 @@ sub do_main {
     my $schema = $self->get_schema();
     my @rows   = $BDAY->get_listing(
         {
-            schema   => $schema,
-            where    => $search,
+            schema      => $schema,
+            where       => $search,
         }
     );
 
@@ -132,7 +132,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj, { skipinvalid => 1 } );
+        my $json = to_json( $obj, { allow_blessed => 1 } );
         return( $json );
     }
 
